@@ -629,7 +629,7 @@ typedef TDSRET  tds_func_get_info(TDSSOCKET *tds, TDSCOLUMN *col);
 typedef TDSRET  tds_func_get_data(TDSSOCKET *tds, TDSCOLUMN *col);
 typedef TDS_INT tds_func_row_len(TDSCOLUMN *col);
 typedef TDSRET  tds_func_put_info(TDSSOCKET *tds, TDSCOLUMN *col);
-typedef TDSRET  tds_func_put_data(TDSSOCKET *tds, TDSCOLUMN *col, int bcp7);
+typedef TDSRET  tds_func_put_data(TDSSOCKET *tds, TDSCOLUMN *col, bool bcp7);
 typedef int     tds_func_check(const TDSCOLUMN *col);
 
 typedef struct tds_column_funcs
@@ -785,7 +785,7 @@ typedef enum tds_states
 	TDS_IDLE,	/**< no data expected */
 	TDS_WRITING,	/**< client is writing data */
 	TDS_SENDING,	/**< client would send data */
-	TDS_PENDING,	/**< cilent is waiting for data */
+	TDS_PENDING,	/**< client is waiting for data */
 	TDS_READING,	/**< client is reading data */
 	TDS_DEAD	/**< no connection */
 } TDS_STATE;
@@ -1537,10 +1537,9 @@ int tdsdump_wopen(const wchar_t *filename);
 #endif
 #include <freetds/pushvis.h>
 void tdsdump_close(void);
-void tdsdump_dump_buf(const char* file, unsigned int level_line, const char *msg, const void *buf, size_t length);
+void tdsdump_dump_buf_impl(const char* file, unsigned int level_line, const char *msg, const void *buf, size_t length);
 void tdsdump_col(const TDSCOLUMN *col);
-#undef tdsdump_log
-void tdsdump_log(const char* file, unsigned int level_line, const char *fmt, ...)
+void tdsdump_log_impl(const char* file, unsigned int level_line, const char *fmt, ...)
 #if defined(__GNUC__) && __GNUC__ >= 2
 #if defined(__MINGW32__)
 	__attribute__ ((__format__ (ms_printf, 3, 4)))
@@ -1549,10 +1548,8 @@ void tdsdump_log(const char* file, unsigned int level_line, const char *fmt, ...
 #endif
 #endif
 ;
-#define TDSDUMP_LOG_FAST if (TDS_UNLIKELY(tds_write_dump)) tdsdump_log
-#define tdsdump_log TDSDUMP_LOG_FAST
-#define TDSDUMP_BUF_FAST if (TDS_UNLIKELY(tds_write_dump)) tdsdump_dump_buf
-#define tdsdump_dump_buf TDSDUMP_BUF_FAST
+#define tdsdump_log if (!TDS_UNLIKELY(tds_write_dump)) {} else tdsdump_log_impl
+#define tdsdump_dump_buf if (!TDS_UNLIKELY(tds_write_dump)) {} else tdsdump_dump_buf_impl
 
 extern bool tds_write_dump;
 extern int tds_debug_flags;
@@ -1695,6 +1692,10 @@ typedef struct tds5_colinfo
 	TDS_TINYINT status;
 	TDS_SMALLINT offset;
 	TDS_INT length;
+	bool dflt;
+
+	TDS_INT dflt_size;
+	TDS_UCHAR* dflt_value;
 } TDS5COLINFO;
 
 struct tds_bcpinfo
